@@ -62,6 +62,8 @@ item(_GTK_FRAME_EXTENTS)
 item(_GNOME_PANEL_ACTION)
 item(_GNOME_PANEL_ACTION_MAIN_MENU)
 item(_GNOME_PANEL_ACTION_RUN_DIALOG)
+item(_METACITY_TIMESTAMP_PING)
+item(_METACITY_FOCUS_SET)
 item(_METACITY_SENTINEL)
 item(_METACITY_VERSION)
 item(WM_CLIENT_MACHINE)
