@@ -532,7 +532,7 @@ meta_rectangle_get_minimal_spanning_set_for_region (
    * enough to make this worth bothering.  Further, it is only called from
    * workspace.c:ensure_work_areas_validated (at least as of the time of
    * writing this comment), which in turn should only be called if the
-   * strut list changes or the screen or xinerama size changes.  If it ever
+   * strut list changes or the screen or monitor size changes. If it ever
    * does show up on profiles (most likely because people start using
    * ridiculously huge numbers of partial struts), possible optimizations
    * include:
@@ -761,15 +761,6 @@ meta_rectangle_expand_to_avoiding_struts (MetaRectangle       *rect,
     } /* end loop over struts */
 } /* end meta_rectangle_expand_to_avoiding_struts */
 
-void
-meta_rectangle_free_list_and_elements (GList *filled_list)
-{
-  g_list_foreach (filled_list,
-                  (void (*)(gpointer,gpointer))&g_free, /* ew, for ugly */
-                  NULL);
-  g_list_free (filled_list);
-}
-
 gboolean
 meta_rectangle_could_fit_in_region (const GList         *spanning_rects,
                                     const MetaRectangle *rect)
@@ -1793,21 +1784,21 @@ meta_rectangle_find_onscreen_edges (const MetaRectangle *basic_rect,
   ret = g_list_sort (ret, meta_rectangle_edge_cmp);
 
   /* Free the fixed struts list */
-  meta_rectangle_free_list_and_elements (fixed_strut_rects);
+  g_list_free_full (fixed_strut_rects, g_free);
 
   return ret;
 }
 
 GList*
-meta_rectangle_find_nonintersected_xinerama_edges (
+meta_rectangle_find_nonintersected_monitor_edges (
                                     const MetaRectangle *screen_rect,
-                                    const GList         *xinerama_rects,
+                                    const GList         *monitor_rects,
                                     const GSList        *all_struts)
 {
   /* This function cannot easily be merged with
    * meta_rectangle_find_onscreen_edges() because real screen edges
    * and strut edges both are of the type "there ain't anything
-   * immediately on the other side"; xinerama edges are different.
+   * immediately on the other side"; monitor edges are different.
    */
   GList *ret;
   const GList  *cur;
@@ -1816,10 +1807,10 @@ meta_rectangle_find_nonintersected_xinerama_edges (
   /* Initialize the return list to be empty */
   ret = NULL;
 
-  /* start of ret with all the edges of xineramas that are adjacent to
-   * another xinerama.
+  /* start of ret with all the edges of monitors that are adjacent to
+   * another monitor.
    */
-  cur = xinerama_rects;
+  cur = monitor_rects;
   while (cur)
     {
       MetaRectangle *cur_rect = cur->data;
@@ -1830,7 +1821,7 @@ meta_rectangle_find_nonintersected_xinerama_edges (
           new_edge  = g_new (MetaEdge, 1);
           new_edge->rect = meta_rect (BOX_LEFT (*cur_rect), BOX_TOP (*cur_rect), 0, cur_rect->height);
           new_edge->side_type = META_SIDE_LEFT;
-          new_edge->edge_type = META_EDGE_XINERAMA;
+          new_edge->edge_type = META_EDGE_MONITOR;
           ret = g_list_prepend (ret, new_edge);
         }
       if (BOX_RIGHT(*cur_rect) != BOX_RIGHT(*screen_rect))
@@ -1838,7 +1829,7 @@ meta_rectangle_find_nonintersected_xinerama_edges (
           new_edge  = g_new (MetaEdge, 1);
           new_edge->rect = meta_rect (BOX_RIGHT (*cur_rect), BOX_TOP (*cur_rect), 0, cur_rect->height);
           new_edge->side_type = META_SIDE_RIGHT;
-          new_edge->edge_type = META_EDGE_XINERAMA;
+          new_edge->edge_type = META_EDGE_MONITOR;
           ret = g_list_prepend (ret, new_edge);
         }
       if (BOX_TOP(*cur_rect) != BOX_TOP(*screen_rect))
@@ -1846,7 +1837,7 @@ meta_rectangle_find_nonintersected_xinerama_edges (
           new_edge  = g_new (MetaEdge, 1);
           new_edge->rect = meta_rect (BOX_LEFT (*cur_rect), BOX_TOP (*cur_rect), cur_rect->width, 0);
           new_edge->side_type = META_SIDE_TOP;
-          new_edge->edge_type = META_EDGE_XINERAMA;
+          new_edge->edge_type = META_EDGE_MONITOR;
           ret = g_list_prepend (ret, new_edge);
         }
       if (BOX_BOTTOM(*cur_rect) != BOX_BOTTOM(*screen_rect))
@@ -1854,7 +1845,7 @@ meta_rectangle_find_nonintersected_xinerama_edges (
           new_edge  = g_new (MetaEdge, 1);
           new_edge->rect = meta_rect (BOX_LEFT (*cur_rect), BOX_BOTTOM (*cur_rect), cur_rect->width, 0);
           new_edge->side_type = META_SIDE_BOTTOM;
-          new_edge->edge_type = META_EDGE_XINERAMA;
+          new_edge->edge_type = META_EDGE_MONITOR;
           ret = g_list_prepend (ret, new_edge);
         }
 
