@@ -82,8 +82,12 @@ new_screen_edge (int x, int y, int width, int height, int side_type)
   return temporary;
 }
 
-static MetaEdge*
-new_xinerama_edge (int x, int y, int width, int height, int side_type)
+static MetaEdge *
+new_monitor_edge (int x,
+                  int y,
+                  int width,
+                  int height,
+                  int side_type)
 {
   MetaEdge* temporary;
   temporary = g_new (MetaEdge, 1);
@@ -92,7 +96,7 @@ new_xinerama_edge (int x, int y, int width, int height, int side_type)
   temporary->rect.width  = width;
   temporary->rect.height = height;
   temporary->side_type = side_type;
-  temporary->edge_type = META_EDGE_XINERAMA;
+  temporary->edge_type = META_EDGE_MONITOR;
 
   return temporary;
 }
@@ -316,8 +320,9 @@ get_screen_edges (int which)
   return ret;
 }
 
-static GList*
-get_xinerama_edges (int which_xinerama_set, int which_strut_set)
+static GList *
+get_monitor_edges (int which_monitor_set,
+                   int which_strut_set)
 {
   GList *ret;
   GSList *struts;
@@ -325,8 +330,8 @@ get_xinerama_edges (int which_xinerama_set, int which_strut_set)
   MetaRectangle screenrect;
 
   xins = NULL;
-  g_assert (which_xinerama_set >=0 && which_xinerama_set <= 3);
-  switch (which_xinerama_set)
+  g_assert (which_monitor_set >=0 && which_monitor_set <= 3);
+  switch (which_monitor_set)
     {
     case 0:
       xins = g_list_prepend (xins, new_meta_rect (  0,   0, 1600, 1200));
@@ -356,10 +361,10 @@ get_xinerama_edges (int which_xinerama_set, int which_strut_set)
   screenrect.height = 1200;
 
   struts = get_strut_list (which_strut_set);
-  ret = meta_rectangle_find_nonintersected_xinerama_edges (&screenrect, xins, struts);
+  ret = meta_rectangle_find_nonintersected_monitor_edges (&screenrect, xins, struts);
 
   free_strut_list (struts);
-  meta_rectangle_free_list_and_elements (xins);
+  g_list_free_full (xins, g_free);
 
   return ret;
 }
@@ -600,8 +605,8 @@ test_regions_okay (void)
   tmp = NULL;
   tmp = g_list_prepend (tmp, new_meta_rect (0, 0, 1600, 1200));
   verify_lists_are_equal (region, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (region, g_free);
 
   /*************************************************************/
   /* Make sure test region 1 has the right spanning rectangles */
@@ -611,8 +616,8 @@ test_regions_okay (void)
   tmp = g_list_prepend (tmp, new_meta_rect (0, 20,  400, 1180));
   tmp = g_list_prepend (tmp, new_meta_rect (0, 20, 1600, 1140));
   verify_lists_are_equal (region, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (region, g_free);
 
   /*************************************************************/
   /* Make sure test region 2 has the right spanning rectangles */
@@ -625,8 +630,8 @@ test_regions_okay (void)
   tmp = g_list_prepend (tmp, new_meta_rect (   0,   20,  800, 1130));
   tmp = g_list_prepend (tmp, new_meta_rect (   0,   20, 1600, 1080));
   verify_lists_are_equal (region, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (region, g_free);
 
   /*************************************************************/
   /* Make sure test region 3 has the right spanning rectangles */
@@ -651,8 +656,8 @@ test_regions_okay (void)
   printf ("%s vs. %s\n", region_list, tmp_list);
 #endif
   verify_lists_are_equal (region, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (region, g_free);
 
   /*************************************************************/
   /* Make sure test region 4 has the right spanning rectangles */
@@ -661,8 +666,8 @@ test_regions_okay (void)
   tmp = NULL;
   tmp = g_list_prepend (tmp, new_meta_rect ( 800,   20,  800, 1180));
   verify_lists_are_equal (region, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (region, g_free);
 
   /*************************************************************/
   /* Make sure test region 5 has the right spanning rectangles */
@@ -694,7 +699,7 @@ test_region_fitting (void)
       g_assert (meta_rectangle_contained_in_region (region, &rect) == FALSE ||
                 meta_rectangle_could_fit_in_region (region, &rect) == TRUE);
     }
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (region, g_free);
 
   /* Do some manual tests too */
   region = get_screen_region (1);
@@ -711,14 +716,14 @@ test_region_fitting (void)
   g_assert (meta_rectangle_could_fit_in_region (region, &rect));
   g_assert (!meta_rectangle_contained_in_region (region, &rect));
 
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (region, g_free);
 
   region = get_screen_region (2);
   rect = meta_rect (1000, 50, 600, 1100);
   g_assert (meta_rectangle_could_fit_in_region (region, &rect));
   g_assert (!meta_rectangle_contained_in_region (region, &rect));
 
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (region, g_free);
 
   printf ("%s passed.\n", G_STRFUNC);
 }
@@ -748,7 +753,7 @@ test_clamping_to_region (void)
       g_assert (meta_rectangle_could_fit_in_region (region, &rect) == TRUE);
       g_assert (rect.x == temp.x && rect.y == temp.y);
     }
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (region, g_free);
 
   /* Do some manual tests too */
   region = get_screen_region (1);
@@ -814,7 +819,7 @@ test_clamping_to_region (void)
                                            &min_size);
   g_assert (rect.width == 100 && rect.height == 999999);
 
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (region, g_free);
 
   printf ("%s passed.\n", G_STRFUNC);
 }
@@ -858,7 +863,7 @@ test_clipping_to_region (void)
           g_assert (meta_rectangle_contained_in_region (region, &rect) == TRUE);
         }
     }
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (region, g_free);
 
   /* Do some manual tests too */
   region = get_screen_region (2);
@@ -897,7 +902,7 @@ test_clipping_to_region (void)
                                  &rect);
   g_assert (meta_rectangle_equal (&rect, &temp));
 
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (region, g_free);
 
   printf ("%s passed.\n", G_STRFUNC);
 }
@@ -920,7 +925,7 @@ test_shoving_into_region (void)
           g_assert (meta_rectangle_contained_in_region (region, &rect));
         }
     }
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (region, g_free);
 
   /* Do some manual tests too */
   region = get_screen_region (2);
@@ -967,7 +972,7 @@ test_shoving_into_region (void)
                                     &rect);
   g_assert (meta_rectangle_equal (&rect, &temp));
 
-  meta_rectangle_free_list_and_elements (region);
+  g_list_free_full (region, g_free);
 
   printf ("%s passed.\n", G_STRFUNC);
 }
@@ -1040,8 +1045,8 @@ test_find_onscreen_edges (void)
   tmp = g_list_prepend (tmp, new_screen_edge (1600,    0, 0, 1200, right));
   tmp = g_list_prepend (tmp, new_screen_edge (   0,    0, 0, 1200, left));
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   /*************************************************/
   /* Make sure test region 1 has the correct edges */
@@ -1055,8 +1060,8 @@ test_find_onscreen_edges (void)
   tmp = g_list_prepend (tmp, new_screen_edge ( 400, 1160, 0,   40, right));
   tmp = g_list_prepend (tmp, new_screen_edge (   0,   20, 0, 1180, left));
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   /*************************************************/
   /* Make sure test region 2 has the correct edges */
@@ -1076,8 +1081,8 @@ test_find_onscreen_edges (void)
   tmp = g_list_prepend (tmp, new_screen_edge ( 450, 1150, 0,   50, left));
   tmp = g_list_prepend (tmp, new_screen_edge (   0,   20, 0, 1180, left));
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   /*************************************************/
   /* Make sure test region 3 has the correct edges */
@@ -1111,8 +1116,8 @@ test_find_onscreen_edges (void)
 #endif
 
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   /*************************************************/
   /* Make sure test region 4 has the correct edges */
@@ -1124,8 +1129,8 @@ test_find_onscreen_edges (void)
   tmp = g_list_prepend (tmp, new_screen_edge (1600,   20, 0, 1180, right));
   tmp = g_list_prepend (tmp, new_screen_edge ( 800,   20, 0, 1180, left));
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   /*************************************************/
   /* Make sure test region 5 has the correct edges */
@@ -1133,8 +1138,8 @@ test_find_onscreen_edges (void)
   edges = get_screen_edges (5);
   tmp = NULL;
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   /*************************************************/
   /* Make sure test region 6 has the correct edges */
@@ -1146,14 +1151,14 @@ test_find_onscreen_edges (void)
   tmp = g_list_prepend (tmp, new_screen_edge (1600,   40, 0,  1160, right));
   tmp = g_list_prepend (tmp, new_screen_edge (   0,   40, 0,  1160, left));
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   printf ("%s passed.\n", G_STRFUNC);
 }
 
 static void
-test_find_nonintersected_xinerama_edges (void)
+test_find_nonintersected_monitor_edges (void)
 {
   GList* edges;
   GList* tmp;
@@ -1164,32 +1169,32 @@ test_find_nonintersected_xinerama_edges (void)
   int bottom = META_DIRECTION_BOTTOM;
 
   /*************************************************************************/
-  /* Make sure test xinerama set 0 for with region 0 has the correct edges */
+  /* Make sure test monitor set 0 for with region 0 has the correct edges */
   /*************************************************************************/
-  edges = get_xinerama_edges (0, 0);
+  edges = get_monitor_edges (0, 0);
   tmp = NULL;
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   /*************************************************************************/
-  /* Make sure test xinerama set 2 for with region 1 has the correct edges */
+  /* Make sure test monitor set 2 for with region 1 has the correct edges */
   /*************************************************************************/
-  edges = get_xinerama_edges (2, 1);
+  edges = get_monitor_edges (2, 1);
   tmp = NULL;
-  tmp = g_list_prepend (tmp, new_xinerama_edge (   0,  600, 1600, 0, bottom));
-  tmp = g_list_prepend (tmp, new_xinerama_edge (   0,  600, 1600, 0, top));
+  tmp = g_list_prepend (tmp, new_monitor_edge (   0,  600, 1600, 0, bottom));
+  tmp = g_list_prepend (tmp, new_monitor_edge (   0,  600, 1600, 0, top));
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   /*************************************************************************/
-  /* Make sure test xinerama set 1 for with region 2 has the correct edges */
+  /* Make sure test monitor set 1 for with region 2 has the correct edges */
   /*************************************************************************/
-  edges = get_xinerama_edges (1, 2);
+  edges = get_monitor_edges (1, 2);
   tmp = NULL;
-  tmp = g_list_prepend (tmp, new_xinerama_edge ( 800,   20, 0, 1080, right));
-  tmp = g_list_prepend (tmp, new_xinerama_edge ( 800,   20, 0, 1180, left));
+  tmp = g_list_prepend (tmp, new_monitor_edge ( 800,   20, 0, 1080, right));
+  tmp = g_list_prepend (tmp, new_monitor_edge ( 800,   20, 0, 1180, left));
 #if 0
   #define FUDGE 50
   char big_buffer1[(EDGE_LENGTH+2)*FUDGE], big_buffer2[(EDGE_LENGTH+2)*FUDGE];
@@ -1199,44 +1204,44 @@ test_find_nonintersected_xinerama_edges (void)
          big_buffer1, big_buffer2);
 #endif
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   /*************************************************************************/
-  /* Make sure test xinerama set 3 for with region 3 has the correct edges */
+  /* Make sure test monitor set 3 for with region 3 has the correct edges */
   /*************************************************************************/
-  edges = get_xinerama_edges (3, 3);
+  edges = get_monitor_edges (3, 3);
   tmp = NULL;
-  tmp = g_list_prepend (tmp, new_xinerama_edge ( 900,  600,  700, 0, bottom));
-  tmp = g_list_prepend (tmp, new_xinerama_edge (   0,  600,  700, 0, bottom));
-  tmp = g_list_prepend (tmp, new_xinerama_edge ( 900,  600,  700, 0, top));
-  tmp = g_list_prepend (tmp, new_xinerama_edge (   0,  600,  700, 0, top));
-  tmp = g_list_prepend (tmp, new_xinerama_edge ( 800,  675, 0,  425, right));
-  tmp = g_list_prepend (tmp, new_xinerama_edge ( 800,  675, 0,  525, left));
+  tmp = g_list_prepend (tmp, new_monitor_edge ( 900,  600,  700, 0, bottom));
+  tmp = g_list_prepend (tmp, new_monitor_edge (   0,  600,  700, 0, bottom));
+  tmp = g_list_prepend (tmp, new_monitor_edge ( 900,  600,  700, 0, top));
+  tmp = g_list_prepend (tmp, new_monitor_edge (   0,  600,  700, 0, top));
+  tmp = g_list_prepend (tmp, new_monitor_edge ( 800,  675, 0,  425, right));
+  tmp = g_list_prepend (tmp, new_monitor_edge ( 800,  675, 0,  525, left));
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   /*************************************************************************/
-  /* Make sure test xinerama set 3 for with region 4 has the correct edges */
+  /* Make sure test monitor set 3 for with region 4 has the correct edges */
   /*************************************************************************/
-  edges = get_xinerama_edges (3, 4);
+  edges = get_monitor_edges (3, 4);
   tmp = NULL;
-  tmp = g_list_prepend (tmp, new_xinerama_edge ( 800,  600,  800, 0, bottom));
-  tmp = g_list_prepend (tmp, new_xinerama_edge ( 800,  600,  800, 0, top));
-  tmp = g_list_prepend (tmp, new_xinerama_edge ( 800,  600,  0, 600, right));
+  tmp = g_list_prepend (tmp, new_monitor_edge ( 800,  600,  800, 0, bottom));
+  tmp = g_list_prepend (tmp, new_monitor_edge ( 800,  600,  800, 0, top));
+  tmp = g_list_prepend (tmp, new_monitor_edge ( 800,  600,  0, 600, right));
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   /*************************************************************************/
-  /* Make sure test xinerama set 3 for with region 5has the correct edges */
+  /* Make sure test monitor set 3 for with region 5has the correct edges */
   /*************************************************************************/
-  edges = get_xinerama_edges (3, 5);
+  edges = get_monitor_edges (3, 5);
   tmp = NULL;
   verify_edge_lists_are_equal (edges, tmp);
-  meta_rectangle_free_list_and_elements (tmp);
-  meta_rectangle_free_list_and_elements (edges);
+  g_list_free_full (tmp, g_free);
+  g_list_free_full (edges, g_free);
 
   printf ("%s passed.\n", G_STRFUNC);
 }
@@ -1413,7 +1418,7 @@ main (int argc, char **argv)
 
   /* And now the functions dealing with edges more than boxes */
   test_find_onscreen_edges ();
-  test_find_nonintersected_xinerama_edges ();
+  test_find_nonintersected_monitor_edges ();
 
   /* And now the misfit functions that don't quite fit in anywhere else... */
   test_gravity_resize ();
