@@ -35,12 +35,34 @@
 #include <X11/Xlib.h>   /* must explicitly be included for Solaris; #326746 */
 #include <X11/Xutil.h>  /* Just for the definition of the various gravities */
 
-static gboolean is_verbose = FALSE;
+static const GDebugKey debug_keys[] = {
+  { "focus", META_DEBUG_FOCUS },
+  { "workarea", META_DEBUG_WORKAREA },
+  { "stack", META_DEBUG_STACK },
+  { "sm", META_DEBUG_SM },
+  { "events", META_DEBUG_EVENTS },
+  { "window-state", META_DEBUG_WINDOW_STATE },
+  { "window-ops", META_DEBUG_WINDOW_OPS },
+  { "geometry", META_DEBUG_GEOMETRY },
+  { "placement", META_DEBUG_PLACEMENT },
+  { "ping", META_DEBUG_PING },
+  { "xinerama", META_DEBUG_XINERAMA },
+  { "keybindings", META_DEBUG_KEYBINDINGS },
+  { "sync", META_DEBUG_SYNC },
+  { "startup", META_DEBUG_STARTUP },
+  { "prefs", META_DEBUG_PREFS },
+  { "groups", META_DEBUG_GROUPS },
+  { "resizing", META_DEBUG_RESIZING },
+  { "shapes", META_DEBUG_SHAPES },
+  { "edge-resistance", META_DEBUG_EDGE_RESISTANCE },
+  { "verbose", META_DEBUG_VERBOSE },
+  { "vulkan", META_DEBUG_VULKAN }
+};
+
+static guint debug_flags = 0;
 static gboolean is_debugging = FALSE;
 static gboolean replace_current = FALSE;
 static int no_prefix = 0;
-
-#ifdef WITH_VERBOSE_MODE
 static FILE* logfile = NULL;
 
 static void
@@ -65,8 +87,7 @@ ensure_logfile (void)
 
       if (err != NULL)
         {
-          meta_warning (_("Failed to open debug log: %s\n"),
-                        err->message);
+          g_warning ("Failed to open debug log: %s", err->message);
           g_error_free (err);
           return;
         }
@@ -75,8 +96,8 @@ ensure_logfile (void)
 
       if (logfile == NULL)
         {
-          meta_warning (_("Failed to fdopen() log file %s: %s\n"),
-                        filename, strerror (errno));
+          g_warning ("Failed to fdopen() log file %s: %s",
+                     filename, strerror (errno));
           close (fd);
         }
       else
@@ -87,26 +108,37 @@ ensure_logfile (void)
       g_free (filename);
     }
 }
-#endif
 
-gboolean
-meta_is_verbose (void)
+void
+meta_init_debug (void)
 {
-  return is_verbose;
+  debug_flags = g_parse_debug_string (g_getenv ("META_DEBUG"), debug_keys,
+                                      G_N_ELEMENTS (debug_keys));
+
+  if (debug_flags != 0)
+    ensure_logfile ();
 }
 
 void
-meta_set_verbose (gboolean setting)
+meta_toggle_debug (void)
 {
-#ifndef WITH_VERBOSE_MODE
-  if (setting)
-    meta_fatal (_("Metacity was compiled without support for verbose mode\n"));
-#else
-  if (setting)
-    ensure_logfile ();
-#endif
+  if (debug_flags == 0)
+    {
+      debug_flags = g_parse_debug_string ("all", debug_keys,
+                                          G_N_ELEMENTS (debug_keys));
 
-  is_verbose = setting;
+      ensure_logfile ();
+    }
+  else
+    {
+      debug_flags = 0;
+    }
+}
+
+gboolean
+meta_check_debug_flags (MetaDebugFlags flags)
+{
+  return (debug_flags & flags) != 0;
 }
 
 gboolean
@@ -118,10 +150,8 @@ meta_is_debugging (void)
 void
 meta_set_debugging (gboolean setting)
 {
-#ifdef WITH_VERBOSE_MODE
   if (setting)
     ensure_logfile ();
-#endif
 
   is_debugging = setting;
 }
@@ -172,17 +202,7 @@ utf8_fputs (const char *str,
 }
 
 void
-meta_free_gslist_and_elements (GSList *list_to_deep_free)
-{
-  g_slist_foreach (list_to_deep_free,
-                   (void (*)(gpointer,gpointer))&g_free, /* ew, for ugly */
-                   NULL);
-  g_slist_free (list_to_deep_free);
-}
-
-#ifdef WITH_VERBOSE_MODE
-void
-meta_debug_spew_real (const char *format, ...)
+meta_verbose (const char *format, ...)
 {
   va_list args;
   gchar *str;
@@ -190,36 +210,7 @@ meta_debug_spew_real (const char *format, ...)
 
   g_return_if_fail (format != NULL);
 
-  if (!is_debugging)
-    return;
-
-  va_start (args, format);
-  str = g_strdup_vprintf (format, args);
-  va_end (args);
-
-  out = logfile ? logfile : stderr;
-
-  if (no_prefix == 0)
-    utf8_fputs (_("Window manager: "), out);
-  utf8_fputs (str, out);
-
-  fflush (out);
-
-  g_free (str);
-}
-#endif /* WITH_VERBOSE_MODE */
-
-#ifdef WITH_VERBOSE_MODE
-void
-meta_verbose_real (const char *format, ...)
-{
-  va_list args;
-  gchar *str;
-  FILE *out;
-
-  g_return_if_fail (format != NULL);
-
-  if (!is_verbose)
+  if ((debug_flags & META_DEBUG_VERBOSE) == 0)
     return;
 
   va_start (args, format);
@@ -236,11 +227,9 @@ meta_verbose_real (const char *format, ...)
 
   g_free (str);
 }
-#endif /* WITH_VERBOSE_MODE */
 
-#ifdef WITH_VERBOSE_MODE
 static const char*
-topic_name (MetaDebugTopic topic)
+topic_name (MetaDebugFlags topic)
 {
   switch (topic)
     {
@@ -250,8 +239,6 @@ topic_name (MetaDebugTopic topic)
       return "WORKAREA";
     case META_DEBUG_STACK:
       return "STACK";
-    case META_DEBUG_THEMES:
-      return "THEMES";
     case META_DEBUG_SM:
       return "SM";
     case META_DEBUG_EVENTS:
@@ -272,8 +259,6 @@ topic_name (MetaDebugTopic topic)
       return "KEYBINDINGS";
     case META_DEBUG_SYNC:
       return "SYNC";
-    case META_DEBUG_ERRORS:
-      return "ERRORS";
     case META_DEBUG_STARTUP:
       return "STARTUP";
     case META_DEBUG_PREFS:
@@ -284,10 +269,12 @@ topic_name (MetaDebugTopic topic)
       return "RESIZING";
     case META_DEBUG_SHAPES:
       return "SHAPES";
-    case META_DEBUG_COMPOSITOR:
-      return "COMPOSITOR";
     case META_DEBUG_EDGE_RESISTANCE:
       return "EDGE_RESISTANCE";
+    case META_DEBUG_VERBOSE:
+      return "VERBOSE";
+    case META_DEBUG_VULKAN:
+      return "VULKAN";
     default:
       break;
     }
@@ -298,9 +285,9 @@ topic_name (MetaDebugTopic topic)
 static int sync_count = 0;
 
 void
-meta_topic_real (MetaDebugTopic topic,
-                 const char *format,
-                 ...)
+meta_topic (MetaDebugFlags  topic,
+            const char     *format,
+            ...)
 {
   va_list args;
   gchar *str;
@@ -308,7 +295,7 @@ meta_topic_real (MetaDebugTopic topic,
 
   g_return_if_fail (format != NULL);
 
-  if (!is_verbose)
+  if ((debug_flags & topic) == 0)
     return;
 
   va_start (args, format);
@@ -332,96 +319,6 @@ meta_topic_real (MetaDebugTopic topic,
 
   g_free (str);
 }
-#endif /* WITH_VERBOSE_MODE */
-
-void
-meta_bug (const char *format, ...)
-{
-  va_list args;
-  gchar *str;
-  FILE *out;
-
-  g_return_if_fail (format != NULL);
-
-  va_start (args, format);
-  str = g_strdup_vprintf (format, args);
-  va_end (args);
-
-#ifdef WITH_VERBOSE_MODE
-  out = logfile ? logfile : stderr;
-#else
-  out = stderr;
-#endif
-
-  if (no_prefix == 0)
-    utf8_fputs (_("Bug in window manager: "), out);
-  utf8_fputs (str, out);
-
-  fflush (out);
-
-  g_free (str);
-
-  /* stop us in a debugger */
-  abort ();
-}
-
-void
-meta_warning (const char *format, ...)
-{
-  va_list args;
-  gchar *str;
-  FILE *out;
-
-  g_return_if_fail (format != NULL);
-
-  va_start (args, format);
-  str = g_strdup_vprintf (format, args);
-  va_end (args);
-
-#ifdef WITH_VERBOSE_MODE
-  out = logfile ? logfile : stderr;
-#else
-  out = stderr;
-#endif
-
-  if (no_prefix == 0)
-    utf8_fputs (_("Window manager warning: "), out);
-  utf8_fputs (str, out);
-
-  fflush (out);
-
-  g_free (str);
-}
-
-void
-meta_fatal (const char *format, ...)
-{
-  va_list args;
-  gchar *str;
-  FILE *out;
-
-  g_return_if_fail (format != NULL);
-
-  va_start (args, format);
-  str = g_strdup_vprintf (format, args);
-  va_end (args);
-
-#ifdef WITH_VERBOSE_MODE
-  out = logfile ? logfile : stderr;
-#else
-  out = stderr;
-#endif
-
-  if (no_prefix == 0)
-    utf8_fputs (_("Window manager error: "), out);
-  utf8_fputs (str, out);
-
-  fflush (out);
-
-  g_free (str);
-
-  meta_exit (META_EXIT_ERROR);
-}
 
 void
 meta_push_no_msg_prefix (void)
@@ -437,12 +334,6 @@ meta_pop_no_msg_prefix (void)
   --no_prefix;
 }
 
-void
-meta_exit (MetaExitCode code)
-{
-  exit (code);
-}
-
 gint
 meta_unsigned_long_equal (gconstpointer v1,
                           gconstpointer v2)
@@ -595,11 +486,9 @@ meta_show_dialog (const char *type,
 
   if (error)
     {
-      meta_warning ("%s\n", error->message);
+      g_warning ("%s", error->message);
       g_error_free (error);
     }
 
   return child_pid;
 }
-/* eof util.c */
-
