@@ -150,14 +150,17 @@ validate_or_free_results (GetPropertyResults *results,
   if (res_name == NULL)
     res_name = "unknown";
 
-  meta_warning (_("Window 0x%lx has property %s\nthat was expected to have type %s format %d\nand actually has type %s format %d n_items %d.\nThis is most likely an application bug, not a window manager bug.\nThe window has title=\"%s\" class=\"%s\" name=\"%s\"\n"),
-                results->xwindow,
-                prop_name ? prop_name : "(bad atom)",
-                expected_name ? expected_name : "(bad atom)",
-                expected_format,
-                type_name ? type_name : "(bad atom)",
-                results->format, (int) results->n_items,
-                title, res_class, res_name);
+  g_warning ("Window 0x%lx has property %s\nthat was expected to have type "
+             "%s format %d\nand actually has type %s format %d n_items %d.\n"
+             "This is most likely an application bug, not a window manager "
+             "bug.\nThe window has title=\"%s\" class=\"%s\" name=\"%s\"",
+             results->xwindow,
+             prop_name ? prop_name : "(bad atom)",
+             expected_name ? expected_name : "(bad atom)",
+             expected_format,
+             type_name ? type_name : "(bad atom)",
+             results->format, (int) results->n_items,
+             title, res_class, res_name);
 
   if (type_name)
     XFree (type_name);
@@ -406,8 +409,8 @@ utf8_string_from_results (GetPropertyResults *results,
       char *name;
 
       name = XGetAtomName (results->display->xdisplay, results->xatom);
-      meta_warning (_("Property %s on window 0x%lx contained invalid UTF-8\n"),
-                    name, results->xwindow);
+      g_warning ("Property %s on window 0x%lx contained invalid UTF-8",
+                 name, results->xwindow);
       meta_XFree (name);
       XFree (results->prop);
       results->prop = NULL;
@@ -489,8 +492,10 @@ utf8_list_from_results (GetPropertyResults *results,
           meta_error_trap_push (results->display);
           name = XGetAtomName (results->display->xdisplay, results->xatom);
           meta_error_trap_pop (results->display);
-          meta_warning (_("Property %s on window 0x%lx contained invalid UTF-8 for item %d in the list\n"),
-                        name, results->xwindow, i);
+
+          g_warning ("Property %s on window 0x%lx contained invalid UTF-8 "
+                     "for item %d in the list", name, results->xwindow, i);
+
           meta_XFree (name);
           meta_XFree (results->prop);
           results->prop = NULL;
@@ -578,6 +583,21 @@ counter_from_results (GetPropertyResults *results,
   return TRUE;
 }
 
+static gboolean
+counter_list_from_results (GetPropertyResults  *results,
+                           XSyncCounter       **counters_p,
+                           int                 *n_counters_p)
+{
+  if (!validate_or_free_results (results, 32, XA_CARDINAL, FALSE))
+    return FALSE;
+
+  *counters_p = (XSyncCounter*) results->prop;
+  *n_counters_p = results->n_items;
+  results->prop = NULL;
+
+  return TRUE;
+}
+
 gboolean
 meta_prop_get_window (MetaDisplay *display,
                       Window       xwindow,
@@ -997,7 +1017,7 @@ meta_prop_get_values (MetaDisplay   *display,
                * property notify on an atom we don't care about.
                */
               if (values[i].atom != None)
-                meta_bug ("META_PROP_VALUE_INVALID requested in %s\n", G_STRFUNC);
+                g_error ("META_PROP_VALUE_INVALID requested in %s", G_STRFUNC);
               break;
             case META_PROP_VALUE_UTF8_LIST:
             case META_PROP_VALUE_UTF8:
@@ -1033,6 +1053,7 @@ meta_prop_get_values (MetaDisplay   *display,
               values[i].required_type = XA_WM_SIZE_HINTS;
               break;
             case META_PROP_VALUE_SYNC_COUNTER:
+            case META_PROP_VALUE_SYNC_COUNTER_LIST:
               values[i].required_type = XA_CARDINAL;
               break;
             default:
@@ -1190,6 +1211,12 @@ meta_prop_get_values (MetaDisplay   *display,
                                      &values[i].v.xcounter))
             values[i].type = META_PROP_VALUE_INVALID;
           break;
+        case META_PROP_VALUE_SYNC_COUNTER_LIST:
+          if (!counter_list_from_results (&results,
+                                          &values[i].v.xcounter_list.counters,
+                                          &values[i].v.xcounter_list.n_counters))
+            values[i].type = META_PROP_VALUE_INVALID;
+          break;
         default:
           break;
         }
@@ -1244,6 +1271,9 @@ free_value (MetaPropValue *value)
       break;
     case META_PROP_VALUE_SYNC_COUNTER:
       break;
+    case META_PROP_VALUE_SYNC_COUNTER_LIST:
+      meta_XFree (value->v.xcounter_list.counters);
+      break;
     default:
       break;
     }
