@@ -56,7 +56,7 @@ typedef enum
 typedef enum
 {
   META_EDGE_WINDOW,
-  META_EDGE_XINERAMA,
+  META_EDGE_MONITOR,
   META_EDGE_SCREEN
 } MetaEdgeType;
 
@@ -186,15 +186,6 @@ void     meta_rectangle_expand_to_avoiding_struts (
                                          const MetaDirection  direction,
                                          const GSList        *all_struts);
 
-/* Free the list created by
- *   meta_rectangle_get_minimal_spanning_set_for_region()
- * or
- *   meta_rectangle_find_onscreen_edges ()
- * or
- *   meta_rectangle_find_nonintersected_xinerama_edges()
- */
-void     meta_rectangle_free_list_and_elements (GList *filled_list);
-
 /* could_fit_in_region determines whether one of the spanning_rects is
  * big enough to contain rect.  contained_in_region checks whether one
  * actually contains it.
@@ -278,12 +269,12 @@ GList* meta_rectangle_remove_intersections_with_boxes_from_edges (
 GList* meta_rectangle_find_onscreen_edges (const MetaRectangle *basic_rect,
                                            const GSList        *all_struts);
 
-/* Finds edges between adjacent xineramas which are not covered by the given
+/* Finds edges between adjacent monitors which are not covered by the given
  * struts.
  */
-GList* meta_rectangle_find_nonintersected_xinerama_edges (
+GList* meta_rectangle_find_nonintersected_monitor_edges (
                                            const MetaRectangle *screen_rect,
-                                           const GList         *xinerama_rects,
+                                           const GList         *monitor_rects,
                                            const GSList        *all_struts);
 
 #endif /* META_BOXES_H */
