@@ -28,13 +28,10 @@
 #define meta_XFree(p) do { if ((p)) XFree ((p)); } while (0)
 
 Display *meta_display_get_xdisplay (MetaDisplay *display);
-MetaCompositor *meta_display_get_compositor (MetaDisplay *display);
 MetaScreen *meta_display_get_screen (MetaDisplay *display);
 
 gboolean meta_display_has_shape (MetaDisplay *display);
 
-MetaScreen *meta_display_screen_for_root (MetaDisplay *display,
-                                          Window       xroot);
 MetaWindow *meta_display_get_focus_window (MetaDisplay *display);
 
 int meta_display_get_damage_event_base (MetaDisplay *display);
