@@ -2,9 +2,9 @@
 
 /* Metacity X property convenience routines */
 
-/* 
+/*
  * Copyright (C) 2001 Havoc Pennington
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
@@ -14,7 +14,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,9 +27,7 @@
 #include "display.h"
 #include <X11/Xutil.h>
 
-#ifdef HAVE_XSYNC
 #include <X11/extensions/sync.h>
-#endif
 
 /* Copied from Lesstif by way of GTK. Rudimentary docs can be
  * found in some Motif reference guides online.
@@ -155,7 +153,8 @@ typedef enum
   META_PROP_VALUE_WM_HINTS,
   META_PROP_VALUE_CLASS_HINT,
   META_PROP_VALUE_SIZE_HINTS,
-  META_PROP_VALUE_SYNC_COUNTER /* comes back as CARDINAL */
+  META_PROP_VALUE_SYNC_COUNTER, /* comes back as CARDINAL */
+  META_PROP_VALUE_SYNC_COUNTER_LIST /* comes back as CARDINAL */
 } MetaPropValueType;
 
 /* used to request/return/store property values */
@@ -164,7 +163,7 @@ typedef struct
   MetaPropValueType type;
   Atom atom;
   Atom required_type; /* autofilled if None */
-  
+
   union
   {
     char *str;
@@ -173,16 +172,20 @@ typedef struct
     gulong cardinal;
     XWMHints *wm_hints;
     XClassHint class_hint;
-#ifdef HAVE_XSYNC
     XSyncCounter xcounter;
-#endif
-    
+
+    struct
+    {
+      gulong *counters;
+      int     n_counters;
+    } xcounter_list;
+
     struct
     {
       XSizeHints   *hints;
       unsigned long flags;
     } size_hints;
-    
+
     struct
     {
       gulong *cardinals;
@@ -200,7 +203,7 @@ typedef struct
       Atom *atoms;
       int   n_atoms;
     } atom_list;
-    
+
   } v;
 
 } MetaPropValue;
