@@ -45,10 +45,8 @@ MetaWindowMenu* meta_window_menu_new      (MetaFrames         *frames,
                                            MetaWindowMenuFunc  func,
                                            gpointer            data);
 void            meta_window_menu_popup    (MetaWindowMenu     *menu,
-                                           int                 root_x,
-                                           int                 root_y,
-                                           int                 button,
-                                           guint32             timestamp);
+                                           const GdkRectangle *rect,
+                                           const GdkEvent     *event);
 void            meta_window_menu_free     (MetaWindowMenu     *menu);
 
 
